@@ -66,6 +66,9 @@ learning_rate = float(input("Enter the learning rate: "))
 batch_size = int(input("Enter the batch size: "))
 
 wandb.login(key=api_key)
+wandb.init(project_name=project_name, run_name=run_name)
+wandb.config = {"learning_rate": learning_rate, "batch_size": batch_size}
+
 
 
 # constants
@@ -661,7 +664,6 @@ class SoundStreamTrainer(nn.Module):
             multiscale_discr_optim.step()
 
         # build pretty printed losses
-
         losses_str = f"{steps}: soundstream total loss: {logs['loss']:.3f}, soundstream recon loss: {logs['recon_loss']:.3f}"
 
         if log_losses:
@@ -680,6 +682,7 @@ class SoundStreamTrainer(nn.Module):
         # log
 
         self.print(losses_str)
+        wandb.log({"loss": f"{logs['loss']:.3f}", "step": steps})
 
         # update exponential moving averaged generator
 
@@ -733,7 +736,7 @@ class SoundStreamTrainer(nn.Module):
         while self.steps < self.num_train_steps:
             logs = self.train_step()
             log_fn(logs)
-
+        wandb.finish()
         self.print('training complete')
 
 # semantic transformer trainer
